@@ -6,7 +6,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::JSON qw(decode_json to_json);
 use GraphQL::Execution qw(execute);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 my @DEFAULT_METHODS = qw(get post);
 my $EXECUTE = sub {
@@ -345,10 +345,10 @@ add "&raw" to the end of the URL within a browser.
         onEditQuery: onEditQuery,
         onEditVariables: onEditVariables,
         onEditOperationName: onEditOperationName,
-        query: <%= $queryString %>,
-        response: <%= $resultString %>,
-        variables: <%= $variablesString %>,
-        operationName: <%= $operationName %>,
+        query: <%== $queryString %>,
+        response: <%== $resultString %>,
+        variables: <%== $variablesString %>,
+        operationName: <%== $operationName %>,
       }),
       document.body
     );
